/* 
 * ToDoInspector - controller for the ToDoList application
 *
 * You may freely copy, distribute and reuse the code in this example.
 * This code is provided AS IS without warranty of any kind, expressed 
 * or implied, as to its fitness for any particular use.
 *
 * Copyright 1995 Ralph Zazula (zazula@running-start.com).  All Rights Reserved.
 *
 */

#import <appkit/appkit.h>
#import "ToDoItems.h"

#define TODO_FILE "%s/Library/RZToDo/DEFAULT.rz2do"

@class ToDoItem;

@interface ToDoController:Object
{
	id	addButton;
	id	browser;
	id	clearButton;
	id	dateField;
	id	modifyButton;
	id	priorityField;
	id	removeButton;
	id	subjectField;
	id	theText;
	id	bodyBox;
	id	splitView;
	id	window;
	id	infoPanel;
	id infoBuildText;
	
	id	todoList;
	id	inspector;

	BOOL showPending;
	BOOL showCompleted;
	BOOL showPrivate;
}

+ initialize;
- appDidInit:sender;
- appWillTerminate:sender;
- info:sender;
- printBuildInfo:sender;
- inspector:sender;
- dirty:sender;
- clean:sender;
- disableEditing;
- enableEditing;
- (BOOL)showPending;
- (BOOL)showCompleted;
- (BOOL)showPrivate;
- setShowPending:(BOOL)flag;
- setShowCompleted:(BOOL)flag;
- setShowPrivate:(BOOL)flag;
- save:sender;
- (long)dueDateFrom:(const char *)s;
- new:sender;
- clear:sender;
- doubleClick:sender;
- modify:sender;
- remove:sender;
- timestamp:sender;
/* insert a time stamp */

- displayItem:(ToDoItem *)item;
- selectItem:(ToDoItem *)item;
- singleClick:sender;
- update;
/*
 * redisplay the browser
 */


/*** as the browser's delegate ***/

- _fillCell:theCell forItem:(ToDoItem *)item;
- (int)browser:sender fillMatrix:matrix inColumn:(int)column;

/*** as the window's delegate ***/

- windowWillClose:sender;
- selectedItems;

/*** for the DO server ***/

- toDoList;
- addItem:(id <ToDoItems>)anItem;
- removeItem:anItem;

/*** as the SplitView's delegate ***/

- splitView:sender getMinY:(NXCoord *)minY maxY:(NXCoord *)maxY ofSubviewAt:(int)offset;
- splitView:sender resizeSubviews:(const NXSize *)oldSize;
- splitViewDidResizeSubviews:sender;

/*** as the text delegate for the UI ***/

- textDidChange:sender;
- (BOOL)textWillEnd:sender;
- addItem:(id)pasteboard userData:(const char *)userData error:(char **)msg;
- validRequestorForSendType:(NXAtom)sendType andReturnType:(NXAtom)returnType;
- (BOOL)writeSelectionToPasteboard:(Pasteboard *)pboard types:(NXAtom *)types;


@end

@interface ToDoController(Pasteboard)
- copy:sender;
- paste:sender;
- cut:sender;
- delete:sender;

/*** utility methods used by cut/copy/paste and services ***/

- copyToPasteboard:(Pasteboard *)pboard;
- pasteFromPasteboard:(Pasteboard *)pboard;
@end
